summaryrefslogtreecommitdiff
path: root/examples/custom_stanzas/custom_stanza_provider.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/custom_stanzas/custom_stanza_provider.py')
-rwxr-xr-xexamples/custom_stanzas/custom_stanza_provider.py26
1 files changed, 13 insertions, 13 deletions
diff --git a/examples/custom_stanzas/custom_stanza_provider.py b/examples/custom_stanzas/custom_stanza_provider.py
index 0ebdb77e..163f307d 100755
--- a/examples/custom_stanzas/custom_stanza_provider.py
+++ b/examples/custom_stanzas/custom_stanza_provider.py
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
@@ -14,35 +14,35 @@ import logging
import getpass
from optparse import OptionParser
-import sleekxmpp
+import slixmpp
-from sleekxmpp import ClientXMPP, Iq
-from sleekxmpp.exceptions import IqError, IqTimeout, XMPPError
-from sleekxmpp.xmlstream import register_stanza_plugin
-from sleekxmpp.xmlstream.handler import Callback
-from sleekxmpp.xmlstream.matcher import StanzaPath
+from slixmpp import ClientXMPP, Iq
+from slixmpp.exceptions import IqError, IqTimeout, XMPPError
+from slixmpp.xmlstream import register_stanza_plugin
+from slixmpp.xmlstream.handler import Callback
+from slixmpp.xmlstream.matcher import StanzaPath
from stanza import Action
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
# throughout SleekXMPP, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
+ from slixmpp.util.misc_ops import setdefaultencoding
setdefaultencoding('utf8')
else:
raw_input = input
-class ActionBot(sleekxmpp.ClientXMPP):
+class ActionBot(slixmpp.ClientXMPP):
"""
- A simple SleekXMPP bot that receives a custom stanza
+ A simple Slixmpp bot that receives a custom stanza
from another client.
"""
def __init__(self, jid, password):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
+ slixmpp.ClientXMPP.__init__(self, jid, password)
# The session_start event will be triggered when
# the bot establishes its connection with the server
@@ -14,35 +14,35 @@ import logging
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
+# throughout Slixmpp, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):